<?php
/**
 * ArchivierungsPlugin.class.php
 *
 * Diese Datei enthlt die Hauptklasse des Plugins
 * Dieses Plugin basiert auf PHP5 und steht unter der GPL.
 *
 * @author      Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @package     ArchivierungsPlugin
 * @version     1.2
 */

// IMPORTS
require_once 'classes/ArchivDB.class.php';

/**
 * Hauptklasse des Plugins - erzeugt ein Objekt des Plugins
 *
 * Dient als Frontcontroller fr das Plugin.
 *
 */
class ArchivierungsPlugin extends StudIPPlugin implements AdministrationPlugin
{
    private $template_factory;
    public $user, $perm;

    /**
     * Konstruktor
     *
     * @return ePruefung
     */
    public function __construct()
    {
        global $user, $perm, $auth;
        parent::__construct();

        $this->user = $user;
        $this->perm = $perm;
        $this->username = (Request::get('username'))? Request::get('username') : $auth->auth['uname'];
        $this->icon = $this->getPluginURL().'/img/book_open.png';
        $this->template_factory = new Flexi_TemplateFactory(dirname(__FILE__).'/templates');
        $this->layout =  $GLOBALS['template_factory']->open('layouts/base');

        $this->showNavigation();

        $GLOBALS['_include_additional_header'] .= '<script src="'.$this->getPluginURL().'/js/archiv.js" type="text/javascript"></script>'."\n";
    }

    /**
     * Zeigt einen Reiter im Adminbereich an
     */
    private function showNavigation()
    {
        if ($this->perm->have_perm('root')) {
            $navigation = new Navigation(_(' Veranstaltungen archivieren'), PluginEngine::getURL($this, array(), 'show'));
            // an die passenden stellen einhngen
            Navigation::addItem('/admin/plugins/archiv', $navigation); //adminbereich
            Navigation::addItem('/start/admin_course/archiv', $navigation); //startseite
        }
    }

    /**
     * Zeigt auf allen Seiten die ePrfung Subnavigation
     *
     */
    private function showMenue()
    {
        Navigation::activateItem('/admin/plugins/archiv');

        $links = array
        (
            'manualArchiv' => PluginEngine::getURL($this, array(), 'manualArchiv'),
            'protectCourses' => PluginEngine::getURL($this, array(), 'protectCourses'),
            'configAutoArchiv' => PluginEngine::getURL($this, array(), 'configAutoArchiv'),
            'listArchiv' => PluginEngine::getURL($this, array(), 'listArchiv'),
            'listBrokenArchiv' => PluginEngine::getURL($this, array(), 'listBrokenArchiv')
        );
        $template = $this->template_factory->open('menue');
        $template->set_attribute('links', $links);
        return $template->render();
    }

    /**
     * Hauptfunktion. Redirect to actionmanualArchiv
     *
     */
    public function show_action()
    {
        $this->manualArchiv_action();
    }

    /**
     * Enter description here...
     *
     */
    public function manualArchiv_action()
    {
        if (!$this->perm->have_perm('root')) {
            throw new Studip_AccessDeniedException("Sie haben nicht die Berechtigung diese Seite aufzurufen.");
        }

        $template = $this->template_factory->open('manual_get');
        $template->set_layout($this->layout);
        $template->menue = $this->showMenue();
        $template->institutes = ArchivDB::getInstitutesByFaculty();
        $template->semesters = SemesterData::getInstance()->getAllSemesterData();
        $template->current = SemesterData::getInstance()->getCurrentSemesterData();
        $template->infobox = $this->getInfobox('2');

        //Kurse anzeigen
        if (Request::submitted('manualsearch')) {
            $courses = ArchivDB::getCourses(Request::get('institut'), Request::get('semester'), $this->getLastActivity(), Request::get('duration'), Request::getArray('semclass'));
            if (count($courses) == 0) {
                $template->message = Messagebox::info('Es wurden keine Veranstaltungen mit diesen Kriterien zum Archivieren gefunden.');
            } else {
                $_SESSION['archivierungsplugin']['semclass'] = Request::get('semclass');
                $template = $this->template_factory->open('manual_show');
                $template->set_layout($GLOBALS['template_factory']->open('layouts/base_without_infobox'));
                $template->menue = $this->showMenue();

                $template->set_attribute('institut', Request::get('institut'));
                $template->set_attribute('institut_name', ArchivDB::getInstitutName(Request::get('institut')));
                $template->set_attribute('semester', SemesterData::getInstance()->getSemesterData(Request::get('semester')));
                $template->set_attribute('inaktiv', $this->getLastActivity());
                $template->set_attribute('backlink', PluginEngine::getURL($this, array(), 'manualArchiv'));
                $template->set_attribute('courses', $courses);
            }
        }
        //Kurse archivieren
        elseif (Request::submitted('doArchive')) {
            $template = $this->template_factory->open('manual_result');
            $template->set_layout($GLOBALS['template_factory']->open('layouts/base_without_infobox'));
            $template->menue = $this->showMenue();
            $template->set_attribute('backlink', PluginEngine::getURL($this, array(), 'manualArchiv'));
            $template->courses = ArchivDB::doArchiveCourses(Request::getArray('selectedCourses'), Request::get('semester'));
        }
        echo $template->render();
    }

    /**
     * Zeigt die bersicht zum Schtzen von Veranstaltungen vor dem Archivieren
     *
     */
    public function protectCourses_action()
    {
        if (!$this->perm->have_perm('root')) {
            throw new Studip_AccessDeniedException("Sie haben nicht die Berechtigung diese Seite aufzurufen.");
        }

        $template = $this->template_factory->open('protect_get');
        $template->set_layout($this->layout);
        $template->menue = $this->showMenue();
        $template->infobox = $this->getInfobox('4');
        $template->institutes = ArchivDB::getInstitutesByFaculty();
        $template->semesters = SemesterData::getInstance()->getAllSemesterData();
        $template->current = SemesterData::getInstance()->getCurrentSemesterData();

        //Kurse anzeigen
        if (Request::submitted('protectsearch')) {
            $courses = ArchivDB::getCourses(Request::get('institut'), Request::get('semester'), $this->getLastActivity(), Request::get('duration'), Request::getArray('semclass'));
            if (count($courses) == 0) {
                $template->message = Messagebox::info('Es wurden keine Veranstaltungen mit diesen Kriterien zum Schtzen vor dem Archivieren gefunden.');
            } else {
                $_SESSION['archivierungsplugin']['semclass'] = Request::get('semclass');
                $template = $this->template_factory->open('protect_show');
                $template->set_layout($GLOBALS['template_factory']->open('layouts/base_without_infobox'));
                $template->menue = $this->showMenue();

                $template->set_attribute('institut_name', ArchivDB::getInstitutName( Request::get('institut')));
                $template->set_attribute('semester', SemesterData::getInstance()->getSemesterData(Request::get('semester')));
                $template->set_attribute('inaktiv', $this->getLastActivity());
                $template->set_attribute('courses', $courses);
            }
        }
        //Kurse schtzen
        elseif (Request::submitted('doNotArchive')) {
            $results = ArchivDB::protectCourses(Request::getArray('selectedCourses'));
            $template->message = MessageBox::success($results.' Veranstaltungen wurden vor dem Archivieren geschtzt.');
        }
        $template->set_attribute('backlink', PluginEngine::getURL($this, array(), 'protectCourses'));
        echo $template->render();
    }

    /**
     * Zeigt die Konfigurationswerte an und bietet Mglichkeiten diese Einstellungen zu verndern.
     *
     */
    public function configAutoArchiv_action()
    {
        if (!$this->perm->have_perm('root')) {
            throw new Studip_AccessDeniedException("Sie haben nicht die Berechtigung diese Seite aufzurufen.");
        }

        $template = $this->template_factory->open('config');
        $template->set_layout($this->layout);
        $template->menue = $this->showMenue();
        $template->infobox = $this->getInfobox('1');

        $template->set_attribute('count_semester', ArchivDB::countSemester());
        $template->set_attribute('count_courses', ArchivDB::countCourses());
        $template->set_attribute('lastChange', ArchivDB::getLastArchivDate());
        $template->set_attribute('count_files', ArchivDB::countFiles());
        $template->set_attribute('count_boards', ArchivDB::countBoards());
        $template->set_attribute('count_wikis', ArchivDB::countWikis());
        echo $template->render();
    }

    /**
     * Zeigt eine Liste aller archivierten Veranstaltungen an
     * und bietet die Funktion archivierte Veranstaltungen endgltig zu lschen.
     *
     */
    public function listArchiv_action()
    {
        if (!$this->perm->have_perm('root')) {
            throw new Studip_AccessDeniedException("Sie haben nicht die Berechtigung diese Seite aufzurufen.");
        }

        $template = $this->template_factory->open('list_archiv');
        $template->set_layout($GLOBALS['template_factory']->open('layouts/base_without_infobox'));

        // veranstaltungen lschen
        if (Request::submitted('deletecourses')) {
            $name = 'selectedCourses'.$_REQUEST['index'];
            $courses = $_REQUEST[$name];
            $template = $this->template_factory->open('delete_result');
            $template->set_layout($GLOBALS['template_factory']->open('layouts/base_without_infobox'));
            $template->set_attribute('results', ArchivDB::deleteCourses($courses));
        }
        // archiv anzeigen
        else {
            $template->set_attribute('semesters', ArchivDB::getArchivedSemesters());
            //semester ausgewhlt
            if(Request::submitted('semester')) {
                $template->set_attribute('semester',Request::get('semester'));
                $template->set_attribute('pluginpfad', $this->getPluginURL());
                $template->set_attribute('list', ArchivDB::getArchivedCourses(Request::get('semester')));
            }
        }

        $template->menue = $this->showMenue();
        $template->set_attribute('link', PluginEngine::getURL($this, array(), 'listArchiv'));
        echo $template->render();
    }

    /**
     * Enter description here...
     *
     */
    public function listBrokenArchiv_action()
    {
        if (!$this->perm->have_perm('root')) {
            throw new Studip_AccessDeniedException("Sie haben nicht die Berechtigung diese Seite aufzurufen.");
        }

        $template = $this->template_factory->open('list_brokenarchiv');
        $template->set_layout($GLOBALS['template_factory']->open('layouts/base_without_infobox'));
        $template->menue = $this->showMenue();
        $template->set_attribute('list', ArchivDB::getBrokenCourses());

        // veranstaltungen lschen
        if (Request::submitted('deletecourses')) {
            $template = $this->template_factory->open('delete_result');
            $template->set_layout($GLOBALS['template_factory']->open('layouts/base_without_infobox'));
            $template->menue = $this->showMenue();
            $template->set_attribute('results', ArchivDB::deleteCourses(Request::get('selectedCourses')));
            $template->set_attribute('backlink', PluginEngine::getURL($this, array(), 'listBrokenArchiv'));
        }
        echo $template->render();
    }


    /**
     * Gibt die Inaktive Zeit in Sekunden zurck
     *
     * @return int
     */
    private function getLastActivity()
    {
        //inaktivittszeitraum
        if (Request::get('lastActivity_2') == "monat") {
            $months = 1;
        } elseif (Request::get('lastActivity_2') == "jahr") {
            $months = 12;
        } else {
            //default 1 Jahr
            $_REQUEST['lastActivity_1'] = 1;
            $months = 12;
        }
        return (mktime() - (Request::get('lastActivity_1') * $months * 60*60*24*31));
    }

    /**
     * Gibt je nach id die passende Infobox aus
     *
     * @param int $id
     * @return array $infobox
     */
    private function getInfobox($id = '1')
    {
        // Infobox
        if($id == '1')
        {
            $infobox = array(
                array("kategorie" => _("Information:"),
                    "eintrag" => array(
                        array(
                            "icon" => '../../'.$this->getPluginpath().'/img/information.png',
                            "text" => 'In der Statistik erhalten Sie einen berblick ber die Archivierung.'
                        )
                    )
                )
            );
        }
        elseif($id == '2')
        {
            $infobox = array(
                array("kategorie" => _("Information:"),
                    "eintrag" => array(
                        array(
                            "icon" => '../../'.$this->getPluginpath().'/img/information.png',
                            "text" => 'Whlen Sie die Einrichtung, die Semester und den Inaktivittszeitraum aus. Sie erhalten dann eine Liste aller Veranstaltungen, die diese Kriterien erfllen.'
                        ),
                        array(
                            "icon" => '../../'.$this->getPluginpath().'/img/information.png',
                            "text" => 'Wenn Sie eine Fakultt auswhlen, werden auch alle zugehrigen Institute ausgewhlt.'
                        ),
                        array(
                            "icon" => '../../'.$this->getPluginpath().'/img/information.png',
                            "text" => '<b>Achtung:</b><br/>Beachten Sie, dass eine Archivierung nicht rckgngig gemacht werden kann.'
                        )
                    )
                )
            );
        }
        elseif($id == '3')
        {
            $infobox = array(
                array("kategorie" => _("Information:"),
                    "eintrag" => array(
                        array(
                            "icon" => '../../'.$this->getPluginpath().'/img/information.png',
                            "text" => 'Whlen Sie die Einrichtung aus. Die anderen Parameter kommen aus der Konfiguration der automatischen Archivierung. Sie erhalten dann eine Liste aller Veranstaltungen, die diese Kriterien erfllen.'
                        ),
                        array(
                            "icon" => '../../'.$this->getPluginpath().'/img/information.png',
                            "text" => 'Die Auflistung der Veranstaltungen kann je nach Menge sehr lange dauern.'
                        ),
                        array(
                            "icon" => '../../'.$this->getPluginpath().'/img/information.png',
                            "text" => '<b>Achtung:</b><br/>Beachten Sie, dass eine Archivierung nicht rckgngig gemacht werden kann.'
                        )
                    )
                )
            );
        }
        elseif($id == '4')
        {
            $infobox = array(
                array("kategorie" => _("Information:"),
                    "eintrag" => array(
                        array(
                            "icon" => '../../'.$this->getPluginpath().'/img/information.png',
                            "text" => 'Whlen Sie die Einrichtung, die Semester und den Inaktivittszeitraum aus. Sie erhalten dann eine Liste aller Veranstaltungen, die diese Kriterien erfllen.'
                        ),
                        array(
                            "icon" => '../../'.$this->getPluginpath().'/img/information.png',
                            "text" => 'Die Auflistung der Veranstaltungen kann je nach Menge sehr lange dauern.'
                        ),
                        array(
                            "icon" => '../../'.$this->getPluginpath().'/img/information.png',
                            "text" => '<b>Achtung:</b><br/>Beachten Sie, dass eine beim Schtzen der Veranstaltungen das Datum der letzten Aktivitt auf heute gesetzt wird und nicht rckgngig gemacht werden kann.'
                        )
                    )
                )
            );
        }
        return array('picture' => 'archiv.jpg', 'content' => $infobox);
    }
}