<?php
/**
 * ArchivDB.class.php
 *
 * Diese Datei enthlt die Datenbankfunktionen des Plugins
 * Dieses Plugin basiert auf PHP5 und steht unter der GPL.
 *
 * @author  	Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @package 	ArchivierungsPlugin
 * @copyright 	IBIT 2010
 * @version 	1.2
 */

//Imports
require_once "lib/functions.php";
require_once 'lib/archiv.inc.php';
require_once 'lib/datei.inc.php';

/**
 * Statische DB-Methoden fr das Archivieren
 *
 */
class ArchivDB
{
	/**
	 * Holt eine Liste aller Institute, gruppiert nach Fakultten aus der DB
	 * und gibt sie als array zurck
	 *
	 * @return array
	 *
	 */
	public function getInstitutesByFaculty()
	{
		$db=new DB_Seminar();
		$db2=new DB_Seminar();

		$result = array();
		// Fakultten aus der DB holen
		$db->query("SELECT Institut_id, Name, 1 AS is_fak  FROM Institute WHERE Institut_id=fakultaets_id ORDER BY Name");
		while ($db->next_record())
		{
			#printf ("<option value=\"%s\" style=\"%s\">%s </option>\n", $db->f("Institut_id"),($db->f("is_fak") ? "font-weight:bold;" : ""), htmlReady(substr($db->f("Name"), 0, 70)));
			if ($db->f("is_fak"))
			{
				$db2->query("SELECT Institut_id, Name FROM Institute WHERE fakultaets_id='" .$db->f("Institut_id") . "' AND institut_id!='" .$db->f("Institut_id") . "' ORDER BY Name");
				$institutes = array();
				while ($db2->next_record())
				{
					$inst = array(
						'id' => $db2->f("Institut_id"),
						'name' => $db2->f("Name")
					);
					array_push($institutes, $inst);
				}
			}
			$fak = array(
				'id' => $db->f("Institut_id"),
				'name' =>  $db->f("Name"),
				'is_fak' => ($db->f("is_fak") ? true : false),
				'institutes' => $institutes
			);
			array_push($result, $fak);
		}
		return $result;
	}

    /**
     * Gibt den Namen eines Institutes zu einer Id zurck
     *
     * @param string $id
     * @return string Name
     */
    public static function getInstitutName($id)
    {
        return DBManager::get()->query("SELECT Name FROM Institute WHERE Institut_id='{$id}'")->fetchColumn();
    }

	/**
	 * Enter description here...
	 *
	 * @param string $institut_id
	 * @param string $semester_id
	 * @param unknown_type $lastChange
	 * @return array()
	 */
	public static function getCourses($institut_id, $semester_id, $lastChange, $duration = '0', $semclass)
	{
	    if(empty($semclass)){
	        return array();
	    }

	    //keine semester ausgewhlt, also aktuelles whlen
		if ($semester_id == '0' || empty($semester_id))
		{
		    $semester_id = DBManager::get()->query("SELECT semester_id FROM semester_data WHERE UNIX_TIMESTAMP() BETWEEN beginn AND ende;")->fetch(PDO::FETCH_COLUMN);
		}

		//semesterinfos holen
		$semester_end = DBManager::get()->query("SELECT ende FROM semester_data WHERE semester_id='{$semester_id}'")->fetch(PDO::FETCH_COLUMN);

		//institute bzw. fakultten auswhlen
		$result = array();

		// alle
		if(!empty($institut_id) && $institut_id == "0" )
		{
			$result = self::selectCourses($semester_end, '', $lastChange);
		}
		// nur bestimmte
		else
		{
			// fakultt
			$db = new DB_Seminar;
			$db->queryf("SELECT Institut_id FROM Institute WHERE fakultaets_id = '%s' ORDER BY Name", $institut_id);
			if($db->num_rows() > 0)
			{
				while ($db->next_record())
				{
					$fak_result = self::selectCourses($semester_end, $db->f("Institut_id"), $lastChange, $duration);
					$result = array_merge($result, $fak_result);
				}
			}
			// institut
			else
			{
				$result = self::selectCourses($semester_end, $institut_id, $lastChange, $duration);
			}
		}

		//und hier filter nach veranstaltungstyp
        foreach ($result as $course){
		    if(in_array($GLOBALS['SEM_TYPE'][$course['type']]['class'], $semclass)){
		        $courses[] = $course;
		    }
		}

		return $courses;
	}

	/**
	 * Enter description here...
	 *
	 * @param string $semester_end
	 * @param string $institut_id
	 * @param string $lastChange
	 * @return array
	 */
	private static function selectCourses($semester_end, $institut_id, $lastChange, $duration)
	{
		$db = new DB_Seminar;
		if(!empty($institut_id)) { //institutsauswahl
			$inst_condition = "AND Institut_id='$institut_id'";
		} else {
			$inst_condition = "";
		}
		if($duration != '-1') { // seminardauer auswahl
		    $duration = 'AND duration_time != -1';
		} else {
		    $duration = '';
		}

		$courses = array();

		//kurse aus der DB holen ACHTUNG, kann lange dauern...
		$db->queryf("SELECT Seminar_id, Name, start_time, duration_time, status FROM seminare WHERE start_time <= %s %s %s ORDER BY start_time, Name;", $semester_end, $inst_condition, $duration);
		if($db->num_rows() > 0)
		{
			while ($db->next_record())
			{
				$lastActivity = lastActivity($db->f("Seminar_id"));

				//zusatzinfo institut
				$db2 = new DB_Seminar();
				//zusatzinfo semester
				$db2->queryf("SELECT name FROM semester_data WHERE beginn <= %s AND ende >= %s", $db->f("start_time"), $db->f("start_time"));
				if ($db2->next_record())
				{
					$semester_name = $db2->f("name");
				}
				else
				{
					$semester_name = "Semester unbekannt!";
				}

				//wenn letzt aktivitt lter als angegebener zeitraum, dann hinzufgen
				if ($lastActivity < $lastChange)
				{
					//kurs vorhanden...
					$course = array(
						"seminar_id" => $db->f("Seminar_id"),
						"name" => $db->f("Name"),
					    "duration" => ($db->f("duration_time")=='-1')?'(dauerhafte Veranstaltung)':'',
						"last_activity" => $lastActivity,
						"semester" => $semester_name,
						"institute" => self::getInstitutName($institut_id),
					    "type" => $db->f("status"),
						);
					array_push($courses, $course);
				}
			}
		}
		#echo "<br>selectCourses<br><hr><br>";
		#print_r($courses);
		return $courses;
	}

	/**
	 * Gibt ein Array mit allen archivierten Veranstaltungen, gruppiert nach Semester, sortiert nach Name zuurck
	 *
	 * @return array()
	 */
	public static function getAllArchivedCourses()
	{
		$list = array();
		//Daten aus der Datenbank holen
		//1. semster holen.
		$db = new DB_Seminar;
		$db->query("SELECT DISTINCT semester FROM archiv ORDER BY start_time DESC");
		while ($db->next_record())
		{
			$courses = array();
			$db2 = new DB_Seminar;
			$db2->queryf("SELECT name, dozenten, institute, seminar_id, archiv_file_id, forumdump, wikidump, mkdate FROM archiv WHERE semester = '%s' ORDER BY institute, name", $db->f("semester"));
			while ($db2->next_record())
			{
				$course = array();
				$course['name'] = $db2->f('name');
				$course['dozenten'] = $db2->f('dozenten');
				$course['einrichtung'] = $db2->f('institute');
				$course['dump_id'] = $db2->f('seminar_id');
				$course['date'] = date("d.m.y", $db2->f('mkdate'));
				if($db2->f('archiv_file_id'))
				{
					$course['file_link'] = GetDownloadLink($db2->f('archiv_file_id'), 'Dateisammlung'.'_'.str_replace(' ', '_', substr($db2->f("name"),0,200)).'.zip', 1);
				}
				if($db2->f('wikidump') != '')
				{
					#echo "wiki: '".$db2->f('wikidump')."'<br/>";
					$course['wiki'] = true;
				}
				if($db2->f('forumdump') != '')
				{
					#echo "wiki: '".$db2->f('forumdump')."'<br/>";
					$course['forum'] = true;
				}
				array_push($courses, $course);
			}
			array_push($list, array('semester' => $db->f("semester"), 'courses' => $courses, 'count' => $db2->affected_rows()));
		}
		return $list;
	}

	/**
	 * Holt das Archiv fr ein Semester aus der DB
	 *
	 * @param string $semester
	 * @return array()
	 */
	public static function getArchivedCourses($semester)
	{
		//Daten aus der Datenbank holen
		$courses = array();
		$db2 = new DB_Seminar;
		$db2->queryf("SELECT name, dozenten, institute, seminar_id, archiv_file_id, forumdump, wikidump, mkdate FROM archiv WHERE semester = '%s' ORDER BY institute, name", $semester);
		while ($db2->next_record())
		{
			$course = array();
			$course['name'] = $db2->f('name');
			$course['dozenten'] = $db2->f('dozenten');
			$course['einrichtung'] = $db2->f('institute');
			$course['dump_id'] = $db2->f('seminar_id');
			$course['date'] = date("d.m.y", $db2->f('mkdate'));
			if($db2->f('archiv_file_id'))
			{
				$course['file_link'] = GetDownloadLink($db2->f('archiv_file_id'), 'Dateisammlung'.'_'.str_replace(' ', '_', substr($db2->f("name"),0,200)).'.zip', 1);
			}
			if($db2->f('wikidump') != '')
			{
				#echo "wiki: '".$db2->f('wikidump')."'<br/>";
				$course['wiki'] = true;
			}
			if($db2->f('forumdump') != '')
			{
				#echo "wiki: '".$db2->f('forumdump')."'<br/>";
				$course['forum'] = true;
			}
			$courses[] = $course;
		}
		return array('semester' => $semester, 'courses' => $courses, 'count' => $db2->affected_rows());
	}

    /**
     * Gibt eine Liste aller semester mit archivierten Veranstaltungen zurck
     *
     * @return array()
     */
    public static function getArchivedSemesters()
    {
        return DBManager::Get()->query("SELECT DISTINCT semester FROM archiv ORDER BY semester;")->fetchAll(PDO::FETCH_ASSOC);
    }

	/**
	 * berprft die Datenbank auf kaputte Veranstaltungen und gibt eine Liste
	 * aller defekten Kurse zurck.
	 *
	 * @return array $courses
	 */
	public static function getBrokenCourses()
	{
		$courses = array();
		$db = new DB_Seminar;
		$db->query("SELECT s.Seminar_id AS id, s.Name AS name FROM archiv AS a, seminare AS s WHERE a.seminar_id = s.Seminar_id;");
		while($db->next_record())
		{
			$course = array(
				'id' => $db->f("id"),
				'name' => $db->f("name"),
				'problem' => 'seminare/archiv'
			);
			array_push($courses, $course);
		}
		$db->query("SELECT DISTINCT s.Seminar_id AS id, s.Name AS name FROM archiv_user AS au, seminare AS s WHERE au.seminar_id = s.Seminar_id;");
		while($db->next_record())
		{
			foreach ($courses as $index=>$exist)
			{
				if($exist['id'] == $db->f("id"))
				{
					$courses[$index]['problem'] .= 'und seminare/archiv_user';
					$edit = true;
				}
			}
			if ($edit != true)
			{
				$course = array(
					'id' => $db->f("id"),
					'name' => $db->f("name"),
					'problem' => 'seminare/archiv_user'
				);
				array_push($courses, $course);
			}
		}
		return $courses;
	}

	/**
	 * Enter description here...
	 *
	 * @param array $courses
	 * @return unknown
	 */
	public static function doArchiveCourses($courses, $semester_id)
	{
		$db = new DB_Seminar;
		$archiv_result = array();

		ob_end_clean();
		ob_start();

		//OL-Anpassung: Gibt es die Module-Tabelle?
		$module_db = DBManager::get()->query("SHOW TABLE STATUS LIKE 'module'")->fetch(PDO::FETCH_ASSOC);

		foreach ($courses as $index=>$s_id)
		{
			$archiv = array();

			//OL-Anpassung fr module
			if (!empty($module_db)) {
    		    //NEU, modulzugehrigkeit mit archivieren.
                $semtree_ids = DBManager::get()->query("SELECT sem_tree_id FROM seminar_sem_tree WHERE seminar_id = '{$s_id}'")->fetchAll(PDO::FETCH_COLUMN);
                if (count($semtree_ids) > 0) {
                    foreach ($semtree_ids as $semtree_id)
                    {
                        $kon_ids = DBManager::get()->query("SELECT m.modul_kon_id FROM module m LEFT JOIN mod_zuordnung mz ON m.modul_abst_id = mz.modul_abst_id WHERE mz.sem_tree_id = '{$semtree_id}' AND m.semester = '{$semester_id}'")->fetchAll(PDO::FETCH_COLUMN);
                    }
                    if (count($kon_ids) > 0) {
                        foreach ($kon_ids as $kon_id)
                        {
                            DBManager::get()->exec("INSERT INTO archiv_module (seminar_id, Modul_kon_id) VALUES ('{$s_id}', '{$kon_id}')");
                        }
                    }
                }
			}

			#$msg = " Veranstaltung <b>$name</b> wird archiviert ... <br>";
			// Bevor es wirklich weg ist. kommt das Seminar doch noch schnell ins Archiv
			in_archiv($s_id);
			$archiv['dump_id'] = $s_id;

			// Alle Benutzer aus dem Seminar rauswerfen.
			$db->queryf("DELETE FROM seminar_user WHERE Seminar_id='%s';", $s_id);
			if (($db_ar = $db->affected_rows()) > 0)
			{
				$archiv['user'] = $db_ar;
			}

			// Alle Benutzer aus Wartelisten rauswerfen
			$db->queryf("DELETE FROM admission_seminar_user WHERE seminar_id='%s';", $s_id);

			// Alle Eintraege aus Zuordnungen zu Studiengaenge rauswerfen
			$db->queryf("DELETE FROM admission_seminar_studiengang WHERE seminar_id='%s';", $s_id);

			// Alle beteiligten Institute rauswerfen

			$db->queryf("DELETE FROM seminar_inst WHERE Seminar_id='%s';", $s_id);
			if (($db_ar = $db->affected_rows()) > 0)
			{
				$archiv['institutes'] = $db_ar;
			}

			// user aus den Statusgruppen rauswerfen
			$count = DeleteAllStatusgruppen($s_id);
			if ($count > 0)
			{
				$archiv['groups'] = true;
			}

			// Alle Eintraege aus dem Vorlesungsverzeichnis rauswerfen
			$db_ar = StudipSemTree::DeleteSemEntries(null, $s_id);
			if ($db_ar > 0)
			{
				$archiv['semtree'] = $db_ar;
			}

			// Alle Termine mit allem was dranhaengt zu diesem Seminar loeschen.
			if (($db_ar = delete_range_of_dates($s_id, TRUE)) > 0)
			{
				$archiv['dates'] = $db_ar;
			}

			// Alle weiteren Postings zu diesem Seminar loeschen.
			$db->queryf("DELETE FROM px_topics WHERE Seminar_id='%s';", $s_id);
			if (($db_ar = $db->affected_rows()) > 0)
			{
				$archiv['postings'] = $db_ar;
			}

			// Alle Dokumente/dateien zu diesem Seminar loeschen.
			if (($db_ar = delete_all_documents($s_id)) > 0)
			{
				$archiv['files'] = $db_ar;
			}

			// Freie Seite zu diesem Seminar lschen
			$db->query("DELETE FROM scm WHERE range_id='%s'", $s_id);
			if (($db_ar = $db->affected_rows()) > 0)
			{
				$archiv['site'] = true;
			}

			// delete literatur
			$del_lit = StudipLitList::DeleteListsByRange($s_id);
			if ($del_lit)
			{
				$archiv['literatur'] = $del_lit['list'];
			}

			// Alle News-Verweise auf dieses Seminar lschen
			if ( ($db_ar = StudipNews::DeleteNewsRanges($s_id)) )
			{
				$archiv['news'] = $db_ar;
			}

			//delete entry in news_rss_range
			StudipNews::UnsetRssId($s_id);

			//kill the datafields (statische Methode)
			$archiv['datafields'] = DataFieldEntry::removeAll($s_id);

			//kill all wiki-pages
			$db->queryf("DELETE FROM wiki WHERE range_id='%s';", $s_id);
			if (($db_wiki = $db->affected_rows()) > 0)
			{
				$archiv['wiki'] = $db_wiki;
			}

			$db->queryf("DELETE FROM wiki_links WHERE range_id='%s'", $s_id);
			$db->queryf("DELETE FROM wiki_locks WHERE range_id='%s'", $s_id);

			// kill all the ressources that are assigned to the Veranstaltung (and all the linked or subordinated stuff!)
			if ($RESOURCES_ENABLE)
			{
				$killAssign = new DeleteResourcesUser($s_id);
				$killAssign->delete();
				$archiv['ressource'] = true;
			}

			//kill the object_user_vists for this seminar
			object_kill_visits(null, $s_id);

			// Logging...
			$db->queryf("SELECT seminare.name AS name, seminare.VeranstaltungsNummer AS number, semester_data.name as semester FROM seminare LEFT JOIN semester_data ON (seminare.start_time = semester_data.beginn) WHERE seminare.Seminar_id='%s';", $s_id);
			if ($db->next_record())
			{
				$semlogname=$db->f('number')." ".$db->f('name')." (".$db->f('semester').")";
				$archiv['name'] = $db->f('name');
			}
			else
			{
				$semlogname="unknown sem_id: $s_id";
			}
			log_event("SEM_ARCHIVE", $s_id, NULL, $semlogname);
			// ...logged

			// und das Seminar loeschen.
			$db->queryf("DELETE FROM seminare WHERE Seminar_id= '%s'", $s_id);
			if ($db->affected_rows() == 0)
			{
				$archiv['delete'] = false;
			}
			else
			{
				$archiv['delete'] = true;
			}
			array_push($archiv_result, $archiv);
			$course = $archiv;

?>
	<tr class="<?=($index%2==0)?'steel1':'steelgraulight' ?>">
		<td valign="top" align="right"><?=$index+1 ?>)</td>
		<td><?=$course['name'] ?>
		<ul>
			<? if(!empty($course['user'])): ?><li><b><?=$course['user'] ?></b> Teilnehmer gelscht</li><? endif; ?>
			<? if(!empty($course['institutes'])): ?><li><b><?=$course['institutes'] ?></b> beteiligte Institute gelscht</li><? endif; ?>
			<? if($course['groups'] == true): ?><li>Statusgruppen gelscht</li><? endif; ?>
			<? if(!empty($course['semtree'])): ?><li><b><?=$course['semtree'] ?></b> Eintrge aus dem Vorlesungsverzeichnis gelscht</li><? endif; ?>
			<? if(!empty($course['dates'])): ?><li><b><?=$course['dates'] ?></b> Termine gelscht</li><? endif; ?>
			<? if(!empty($course['postings'])): ?><li><b><?=$course['postings'] ?></b> Eintrge aus dem Forum gelscht</li><? endif; ?>
			<? if(!empty($course['files'])): ?><li><b><?=$course['files'] ?></b> Dateien gelscht</li><? endif; ?>
			<? if($course['site'] == true): ?><li>Frei Seite gelscht</li><? endif; ?>
			<? if(!empty($course['literatur'])): ?><li><b><?=$course['literatur'] ?></b> Eintrge aus dem Literaturverzeichnis gelscht</li><? endif; ?>
			<? if(!empty($course['news'])): ?><li><b><?=$course['news'] ?></b> News gelscht</li><? endif; ?>
			<? if(!empty($course['datafields'])): ?><li><b><?=$course['datafields'] ?></b> Datenfelder gelscht</li><? endif; ?>
			<? if(!empty($course['wiki'])): ?><li><b><?=$course['wiki'] ?></b> Eintrge aus dem Wiki gelscht</li><? endif; ?>
			<? if($course['ressource'] == true): ?><li>Ressourcen gelscht</li><? endif; ?>
			<? if($course['delete'] == true): ?><li><b>Veranstaltung erfolgreich archiviert</b></li>
			<? else: ?><li><b style="color:#FF0000">Fehler: Veranstaltung wurde zwar archiviert, aber nicht gelscht</b></li><? endif; ?>
		</ul>
		</td>
		<td align="right" valign="top">
		<a href="<?=$GLOBALS['ABSOLUTE_URI_STUDIP'] ?>archiv.php?dump_id=<?=$course['dump_id'] ?>"><img src="<?=Assets::url() ?>images/i.gif" border="0" alt="Komplettansicht" title="Komplettansicht" /></a>
		<a href="<?=$GLOBALS['ABSOLUTE_URI_STUDIP'] ?>archiv.php?delete_id=<?=$course['dump_id'] ?>"><img src="<?=Assets::url() ?>images/trash.gif" border="0" alt="Diese Veranstaltung aus dem Archiv entfernen" title="Diese Veranstaltung aus dem Archiv entfernen" /></a>
		</td>
	</tr>
<?
		}
		return ob_get_clean();
	}

    /**
     * Schtzt Veranstaltungen vor dem Archivieren, in dem es das Datum der letzten nderung aktualisiert
     *
     * @param array() $courses
     * @return integer Anzahl Veranstaltungen
     */
    public static function protectCourses($courses)
    {
        foreach ($courses as $seminar_id)
        {
            DBManager::get()->exec("UPDATE seminare SET chdate=UNIX_TIMESTAMP() WHERE Seminar_id='{$seminar_id}'");
        }
        return count($courses);
    }

	/**
	 * Lscht archivierte Veranstaltungen
	 *
	 * @param array $courses
	 */
	public static function deleteCourses($courses)
	{
		#print_r($courses);

		$result = array();
		$db = new DB_Seminar;
		foreach ($courses as $delete_id)
		{
			$info = array();
			//nachgucken, ob archiv vorhanden ist, wenn ja lschen
			$db->query("SELECT name,archiv_file_id,semester FROM archiv WHERE seminar_id='$delete_id';");
			if($db->next_record())
			{
				$info['name'] = $db->f("name");
				$db2 = new DB_Seminar;
				$db2->query("DELETE FROM archiv WHERE seminar_id = '$delete_id';");
				if ($db2->affected_rows())
				{
					$info['delete'] = true;
				}
			}
			//wenn nicht, titel info aus der seminare holen, da es wohl probleme gibt
			else
			{
				$db2 = new DB_Seminar;
				$db2->query("SELECT name FROM seminare WHERE Seminar_id = '$delete_id';");
				if($db->next_record())
				{
					$info['name'] = $db->f("name");
				}
			}
			log_event("SEM_DELETE_FROM_ARCHIVE",$delete_id,NULL,$db->f("name")." (".$db->f("semester").")");
			//dateien lschen
			if ($db->f("archiv_file_id"))
			{
				if (unlink ($ARCHIV_PATH."/".$db->f("archiv_file_id")))
				{
					$info['file'] = true;
				}
				else
				{
					$info['fileerror'] = true;
				}
			}
			//teilnehmer lschen
			$db2->query("DELETE FROM archiv_user WHERE seminar_id='$delete_id';");
			if ($db2->affected_rows())
			{
				$info['user'] = $db2->affected_rows();
			}
			array_push($result, $info);
		}
		return $result;
	}

	/**
	 * Gibt die Anzahl Semester zurck, in denen es archivierte Veranstalungen gibt
	 *
	 * @return int
	 */
	public static function countSemester()
	{
		$db = new DB_Seminar;
		$db->query("SELECT COUNT(DISTINCT semester) AS count FROM archiv;");
		if ($db->next_record())
		{
			return ($db->f('count'));
		}
	}

	/**
	 * Gibt die anzahl archivierter Veranstaltungen zurck
	 *
	 * @return int
	 */
	public static function countCourses()
	{
		$db = new DB_Seminar;
		$db->query("SELECT COUNT(name) AS count FROM archiv;");
		if ($db->next_record())
		{
			return ($db->f('count'));
		}
	}

	/**
	 * Gibt die Anzahl archivierter Veranstaltungen mit Dateien zurck
	 *
	 * @return int
	 */
	public static function countFiles()
	{
		$db = new DB_Seminar;
		$db->query("SELECT COUNT(archiv_file_id) AS files FROM archiv WHERE archiv_file_id != '';");
		if ($db->next_record())
		{
			return ($db->f('files'));
		}
	}

	/**
	 * Enter description here...
	 *
	 * @return int
	 */
	public static function countBoards()
	{
		$db = new DB_Seminar;
		$db->query("SELECT COUNT(seminar_id) AS boards FROM archiv WHERE forumdump != '';");
		if ($db->next_record())
		{
			return ($db->f('boards'));
		}
	}

	/**
	 * Enter description here...
	 *
	 * @return int
	 */
	public static function countWikis()
	{
		$db = new DB_Seminar;
		$db->query("SELECT COUNT(seminar_id) AS wikis FROM archiv WHERE wikidump != '';");
		if ($db->next_record())
		{
			return ($db->f('wikis'));
		}
	}
	/**
	 * Gibt das Datum der letzten Archivierung zurck
	 *
	 * @return string
	 */
	public static function getLastArchivDate()
	{
		$db = new DB_Seminar;
		$db->query("SELECT MAX(mkdate) AS maxdate FROM archiv;");
		if ($db->next_record())
		{
			return (date("d.m.Y", $db->f('maxdate')));
		}
	}
}